#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2019 German Aerospace Center (DLR) and others.
# This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v2.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v20.html
# SPDX-License-Identifier: EPL-2.0

# @file    runner.py
# @author  Lena Kalleske
# @author  Daniel Krajzewicz
# @author  Michael Behrisch
# @author  Jakob Erdmann
# @date    2009-03-26
# @version $Id$

from __future__ import absolute_import
from __future__ import print_function

import os
import sys
import optparse
import random
import copy
import math



# we need to import python modules from the $SUMO_HOME/tools directory
if 'SUMO_HOME' in os.environ:
    tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
    sys.path.append(tools)
else:
    sys.exit("please declare environment variable 'SUMO_HOME'")

from sumolib import checkBinary  # noqa
import traci  # noqa

def run():
    """execute the TraCI control loop"""
    endtime = 4500
    step = 0
    while traci.simulation.getMinExpectedNumber() > 0: #to keep the traci going
        traci.simulationStep()
        while traci.simulation.getTime() > 0: 
            traci.simulationStep()
            if traci.simulation.getTime() == endtime: traci.close()
            step += 0.1
        step += 0.1
    traci.close()
    sys.stdout.flush()


def get_options():
    optParser = optparse.OptionParser()
    optParser.add_option("--nogui", action="store_true",
                         default=False, help="run the commandline version of sumo")
    options, args = optParser.parse_args()
    return options


# this is the main entry point of this script
if __name__ == "__main__":
    options = get_options()
    i = sys.argv[1]
    filenum = int(sys.argv[1])
    
    if 0 <= filenum and filenum <= 9:
        lanevol = 600
        AHDVRatio = 0

    out_dir = '../output/'
    #VOL_lane = sys.argv[1]
    #strat = sys.argv[2]
    #options.nogui=True
    #print(options)
    #run()
    #NUMBER_OF_AHDV = sys.argv[1]
    #VOL = sys.argv[2]
    #AV_MPR = sys.argv[3]
    #print('base',NUMBER_OF_AHDV, VOL, AV_MPR)
    
    #cfg_dir = '../files/{}/{}/{}/'.format(VOL,NUMBER_OF_AHDV,AV_MPR)
    #os.chdir(cfg_dir)
    #print(os.getcwd())
    # this script has been called from the command line. It will start sumo as a
    # server, then connect and run
    if options.nogui:
        sumoBinary = checkBinary('sumo')
    else:
        sumoBinary = checkBinary('sumo-gui')
        #sumoCmd = [sumoBinary, "-c", "induced.sumocfg"]
    out_dir = '../output/'
    # first, generate the route file for this simulation
    #generate_routefile()

    # this is the normal way of using traci. sumo is started as a
    # subprocess and then the python script connects and runs
    #traci.start([sumoBinary, "-c", "merge.sumocfg", "--fcd-output", "fcdoutput.xml"])
    traci.start([sumoBinary, "-c", "merge.sumocfg"])
    #traci.start([sumoBinary, "-c", "merge.sumocfg", "--fcd-output", "{}_{}_base_fcdoutput.xml".format(VOL_lane, strat),'--output-prefix', out_dir])
    #traci.start([sumoBinary, "-c", "merge{}.sumocfg".format(i)])
    #traci.start([sumoBinary, "-c", "merge{}.sumocfg".format(i), "--fcd-output", "{}_{}_base_{}.xml".format(lanevol, AHDVRatio,i),'--output-prefix', out_dir])
    #traci.start([sumoBinary, "-c", "data/cross.sumocfg", "--tripinfo-output", "tripinfo.xml", "--amitran-output","trajectory.xml", "--netstate-dump","RAWtrajectory.xml", "--full-output","Fulltrajectory.xml"])
    run()
